@@ -1,19 +1,6 @@
 #  -*- coding: utf-8 -*-
-#   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
-#  #
-#   This program is free software: you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
-#   (at your option) any later version.
-#  #
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#  #
-#   You should have received a copy of the GNU General Public License
-#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2021 John Mille <john@compose-x.io>
 
 import re
 from copy import deepcopy
@@ -43,6 +30,7 @@ from troposphere.ecs import (
 )
 from troposphere.iam import Policy, PolicyType
 from troposphere.logs import LogGroup
+from troposphere.cloudwatch import MetricDimension
 
 from ecs_composex.common import NONALPHANUM, LOG, FILE_PREFIX
 from ecs_composex.common import keyisset, keypresent
@@ -76,6 +64,10 @@ from ecs_composex.ecs.ecs_params import (
     TASK_ROLE_T,
     TASK_T,
 )
+from ecs_composex.ecs.ecs_predefined_alarms import (
+    PREDEFINED_ALARMS_DEFINITION,
+    PREDEFINED_SERVICE_ALARMS_DEFINITION,
+)
 from ecs_composex.iam import define_iam_policy, add_role_boundaries
 from ecs_composex.resources_import import import_record_properties
 from ecs_composex.secrets.compose_secrets import (
@@ -148,6 +140,7 @@ class ComposeService(object):
         ("x-xray", bool),
         ("x-scaling", dict),
         ("x-network", dict),
+        ("x-alarms", dict),
         ("x-codeguru-profiler", (str, bool, dict)),
     ]
 
@@ -324,7 +317,9 @@ class ComposeService(object):
         default = LogConfiguration(
             LogDriver="awslogs",
             Options={
-                "awslogs-group": self.logical_name,
+                "awslogs-group": Sub(
+                    f"${{{ROOT_STACK_NAME.title}}}/svc/ecs/{self.logical_name}"
+                ),
                 "awslogs-region": Ref(AWS_REGION),
                 "awslogs-stream-prefix": self.name,
             },
@@ -1236,6 +1231,8 @@ class ComposeFamily(object):
         self.ecs_service = None
         self.task_logging_options = {}
         self.stack_parameters = {}
+        self.alarms = {}
+        self.predefined_alarms = {}
         self.set_xray()
         self.sort_container_configs()
         self.handle_iam()
@@ -1281,6 +1278,199 @@ class ComposeFamily(object):
             if xray_service.name not in self.ignored_services:
                 self.ignored_services.append(xray_service)
 
+    def define_predefined_alarm_settings(self, new_settings):
+        """
+        Method to define the predefined alarm settings based on the alarm characteristics
+
+        :param new_settings:
+        :return:
+        """
+        for alarm_name, alarm_def in new_settings["Alarms"].items():
+            if not keyisset("Properties", alarm_def):
+                continue
+            props = alarm_def["Properties"]
+            if not keyisset("MetricName", props):
+                raise KeyError("You must define a MetricName for the pre-defined alarm")
+            metric_name = props["MetricName"]
+            if metric_name == "RunningTaskCount":
+                range_key = "max"
+                if keyisset("range_key", new_settings):
+                    range_key = new_settings["range_key"]
+                new_settings["Settings"][
+                    metric_name
+                ] = self.service_config.scaling.scaling_range[range_key]
+
+    def define_predefined_alarms(self):
+        """
+        Method to define which predefined alarms are available
+        :return: dict of the alarms
+        :rtype: dict
+        """
+
+        finalized_alarms = {}
+        for name, settings in PREDEFINED_SERVICE_ALARMS_DEFINITION.items():
+            if (
+                keyisset("requires_scaling", settings)
+                and not self.service_config.scaling.defined
+            ):
+                LOG.error(
+                    f"No scaling range was defined for the service and rule {name} requires it. Skipping"
+                )
+                continue
+            new_settings = deepcopy(settings)
+            self.define_predefined_alarm_settings(new_settings)
+            finalized_alarms[name] = new_settings
+        return finalized_alarms
+
+    def validate_service_predefined_alarms(self, valid_predefined, service_predefined):
+        if not all(
+            name in valid_predefined.keys() for name in service_predefined.keys()
+        ):
+            raise KeyError(
+                f"For {self.logical_name}, only valid service_predefined alarms are",
+                valid_predefined.keys(),
+                "Got",
+                service_predefined.keys(),
+            )
+
+    def define_default_alarm_settings(self, key, value, settings_key, valid_predefined):
+        if not keyisset(key, self.predefined_alarms):
+            self.predefined_alarms[key] = valid_predefined[key]
+            self.predefined_alarms[key][settings_key] = valid_predefined[key][
+                settings_key
+            ]
+            if isinstance(value, dict) and keyisset(settings_key, value):
+                self.predefined_alarms[key][settings_key] = valid_predefined[key][
+                    settings_key
+                ]
+                for subkey, subvalue in value[settings_key].items():
+                    self.predefined_alarms[key][settings_key][subkey] = subvalue
+
+    def merge_alarm_settings(self, key, value, settings_key, valid_predefined):
+        """
+        Method to merge multiple services alarms definitions
+
+        :param str key:
+        :param dict value:
+        :param str settings_key:
+        :return:
+        """
+        for subkey, subvalue in value[settings_key].items():
+            if isinstance(subvalue, (int, float)) and keyisset(
+                subkey, self.predefined_alarms[key][settings_key]
+            ):
+                set_value = self.predefined_alarms[key][settings_key][subkey]
+                new_value = subvalue
+                LOG.warning(
+                    f"Value for {key}.Settings.{subkey} override from {set_value} to {new_value}."
+                )
+                self.predefined_alarms[key]["Settings"][subkey] = new_value
+
+    def set_merge_alarm_topics(self, key, value):
+        topics = value["Topics"]
+        set_topics = []
+        if keyisset("Topics", self.predefined_alarms[key]):
+            set_topics = self.predefined_alarms[key]["Topics"]
+        else:
+            self.predefined_alarms[key]["Topics"] = set_topics
+        for topic in topics:
+            if isinstance(topic, str) and topic not in [
+                t for t in set_topics if isinstance(t, str)
+            ]:
+                set_topics.append(topic)
+            elif (
+                isinstance(topic, dict)
+                and keyisset("x-sns", topic)
+                and topic["x-sns"]
+                not in [
+                    t["x-sns"]
+                    for t in set_topics
+                    if isinstance(t, dict) and keyisset("x-sns", t)
+                ]
+            ):
+                set_topics.append(topic)
+
+    def assign_predefined_alerts(
+        self, service_predefined, valid_predefined, settings_key
+    ):
+        for key, value in service_predefined.items():
+            if not keyisset(key, self.predefined_alarms):
+                self.define_default_alarm_settings(
+                    key, value, settings_key, valid_predefined
+                )
+            elif (
+                keyisset(key, self.predefined_alarms)
+                and isinstance(value, dict)
+                and keyisset(settings_key, value)
+            ):
+                self.merge_alarm_settings(key, value, settings_key, valid_predefined)
+            if keyisset("Topics", value):
+                self.set_merge_alarm_topics(key, value)
+
+    def handle_alarms(self):
+        """
+        Method to define the alarms for the services.
+        """
+        valid_predefined = self.define_predefined_alarms()
+        LOG.debug(self.logical_name, valid_predefined)
+        if not valid_predefined:
+            return
+        alarm_key = "x-alarms"
+        settings_key = "Settings"
+        for service in self.services:
+            if keyisset(alarm_key, service.definition) and keyisset(
+                "Predefined", service.definition[alarm_key]
+            ):
+                service_predefined = service.definition[alarm_key]["Predefined"]
+                self.validate_service_predefined_alarms(
+                    valid_predefined, service_predefined
+                )
+                self.assign_predefined_alerts(
+                    service_predefined, valid_predefined, settings_key
+                )
+                LOG.debug(self.predefined_alarms)
+
+    def add_container_level_log_group(self, service, log_group_title, expiry):
+        """
+        Method to add a new log group for a specific container/service defined when awslogs-group has been set.
+
+        :param service:
+        :param str log_group_title:
+        :param expiry:
+        """
+        if log_group_title not in self.template.resources:
+            log_group = self.template.add_resource(
+                LogGroup(
+                    log_group_title,
+                    LogGroupName=service.logging.Options["awslogs-group"],
+                    RetentionInDays=expiry,
+                )
+            )
+            policy = Policy(
+                PolicyName=Sub(f"CloudWatchAccessFor${{{ecs_params.SERVICE_NAME_T}}}"),
+                PolicyDocument={
+                    "Version": "2012-10-17",
+                    "Statement": [
+                        {
+                            "Sid": "AllowCloudWatchLoggingToSpecificLogGroup",
+                            "Effect": "Allow",
+                            "Action": [
+                                "logs:CreateLogStream",
+                                "logs:PutLogEvents",
+                            ],
+                            "Resource": GetAtt(log_group, "Arn"),
+                        }
+                    ],
+                },
+            )
+            try:
+                self.exec_role.Policies.append(policy)
+            except AttributeError:
+                setattr(self.exec_role, "Policies", [policy])
+            service.logging.Options.update({"awslogs-group": Ref(log_group)})
+        else:
+            LOG.debug("LOG Group and policy already exist")
+
     def handle_logging(self):
         """
         Method to go over each service logging configuration and accordingly define the IAM permissions needed for
@@ -1319,41 +1509,10 @@ class ComposeFamily(object):
                         },
                     )
                 )
-            elif keyisset("awslogs-group", service.logging.Options):
-                if log_group_title not in self.template.resources:
-                    log_group = self.template.add_resource(
-                        LogGroup(
-                            log_group_title,
-                            LogGroupName=service.logging.Options["awslogs-group"],
-                            RetentionInDays=expiry,
-                        )
-                    )
-                    policy = Policy(
-                        PolicyName=Sub(
-                            f"CloudWatchAccessFor${{{ecs_params.SERVICE_NAME_T}}}"
-                        ),
-                        PolicyDocument={
-                            "Version": "2012-10-17",
-                            "Statement": [
-                                {
-                                    "Sid": "AllowCloudWatchLoggingToSpecificLogGroup",
-                                    "Effect": "Allow",
-                                    "Action": [
-                                        "logs:CreateLogStream",
-                                        "logs:PutLogEvents",
-                                    ],
-                                    "Resource": GetAtt(log_group, "Arn"),
-                                }
-                            ],
-                        },
-                    )
-                    try:
-                        self.exec_role.Policies.append(policy)
-                    except AttributeError:
-                        setattr(self.exec_role, "Policies", [policy])
-                    service.logging.Options.update({"awslogs-group": Ref(log_group)})
-                else:
-                    LOG.debug("LOG Group and policy already exist")
+            elif keyisset("awslogs-group", service.logging.Options) and not isinstance(
+                service.logging.Options["awslogs-group"], (Ref, Sub)
+            ):
+                self.add_container_level_log_group(service, log_group_title, expiry)
             else:
                 service.logging.Options.update(
                     {"awslogs-group": Ref(ecs_params.LOG_GROUP_T)}
