@@ -1,19 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
-#   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
-#  #
-#   This program is free software: you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
-#   (at your option) any later version.
-#  #
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#  #
-#   You should have received a copy of the GNU General Public License
-#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2021 John Mille <john@compose-x.io>
 
 """
 Module to help generate target scaling policies for given alarms.
@@ -334,9 +321,10 @@ class ServiceScaling(object):
         configuration = merge_family_services_scaling(services)
         self.scaling_range = None
         self.target_scaling = None
+        self.defined = False
         if not keyisset("Range", configuration):
-            self.defined = False
             return
+        self.defined = True
         self.scaling_range = configuration["Range"]
         for key in self.target_scaling_keys:
             if keyisset("TargetScaling", configuration) and keyisset(
