@@ -1,19 +1,10 @@
 ﻿#  -*- coding: utf-8 -*-
-#   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@compose-x.io>
-#  #
-#   This program is free software: you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
-#   (at your option) any later version.
-#  #
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#  #
-#   You should have received a copy of the GNU General Public License
-#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2021 John Mille <john@compose-x.io>
+
+"""
+Module to define and match RDS Features to other AWS resources.
+"""
 
 import re
 
@@ -23,17 +14,22 @@ from troposphere.iam import Policy as IamPolicy
 
 from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.common import LOG, keyisset, add_parameters
+from ecs_composex.s3.s3_params import S3_BUCKET_ARN
 
 S3_KEY = "x-s3"
 
 
 def get_s3_bucket_arn_from_resource(db_template, stack, resource):
-    param = Parameter(f"{resource.logical_name}Arn", Type="String")
+    param = Parameter(f"{resource.logical_name}{S3_BUCKET_ARN.title}", Type="String")
     add_parameters(db_template, [param])
     if stack.parent_stack:
         add_parameters(stack.parent_stack.stack_template, [param])
         stack.parent_stack.Parameters.update(
-            {param.title: GetAtt("s3", f"Outputs.{resource.logical_name}Arn")}
+            {
+                param.title: GetAtt(
+                    "s3", f"Outputs.{resource.logical_name}{S3_BUCKET_ARN.title}"
+                )
+            }
         )
     stack.Parameters.update({param.title: Ref(param.title)})
     return Sub(f"${{{param.title}}}/*")
